Struct librespot_core::authentication::Credentials [−][src]
pub struct Credentials {
pub username: String,
pub auth_type: AuthenticationType,
pub auth_data: Vec<u8>,
}The credentials are used to log into the Spotify API.
Fields
username: Stringauth_type: AuthenticationTypeauth_data: Vec<u8>Implementations
impl Credentials[src]
impl Credentials[src]pub fn with_password(
username: impl Into<String>,
password: impl Into<String>
) -> Credentials[src]
username: impl Into<String>,
password: impl Into<String>
) -> Credentials
Intialize these credentials from a username and a password.
Example
use librespot_core::authentication::Credentials; let creds = Credentials::with_password("my account", "my password");
pub fn with_blob(
username: String,
encrypted_blob: &str,
device_id: &str
) -> Credentials[src]
username: String,
encrypted_blob: &str,
device_id: &str
) -> Credentials