pub struct Login5Manager(/* private fields */);Implementations
Sourceimpl Login5Manager
impl Login5Manager
Sourcepub async fn login(
&self,
id: impl Into<String>,
password: impl Into<String>,
) -> Result<(Token, Vec<u8>), Error>
pub async fn login( &self, id: impl Into<String>, password: impl Into<String>, ) -> Result<(Token, Vec<u8>), Error>
Login for android and ios
This request doesn’t require a connected session as it is the entrypoint for android or ios
This request will only work when:
- client_id => android or ios | can be easily adjusted in SessionConfig::default_for_os
- user-agent => android or ios | has to be adjusted in HttpClient::new
Sourcepub async fn auth_token(&self) -> Result<Token, Error>
pub async fn auth_token(&self) -> Result<Token, Error>
Retrieve the access_token via login5
This request will only work when the store credentials match the client-id. Meaning that stored credentials generated with the keymaster client-id will not work, for example, with the android client-id.